@@ -104,7 +104,7 @@ def GameTypeEnum(ctx):
         TurboRandom=8,
         CaptureTheRelic=10,
         SuddenDeath=11,
-        Unknown=13
+        EmpireWars=13
     )
 
 def ObjectTypeEnum(ctx):
@@ -157,20 +157,10 @@ def OperationEnum(ctx):
         action=1,
         sync=2,
         viewlock=3,
-        message=4,
-        de_start=5,
-        aok_start=500,
+        chat=4,
         default="embedded"
     )
 
-def MessageEnum(ctx):
-    """Message Type Enumeration."""
-    return Enum(
-        ctx,
-        start=500,
-        default="chat"
-    )
-
 def ResourceEnum(ctx):
     """Resource Type Enumeration."""
     return Enum(
@@ -211,7 +201,8 @@ def ResourceLevelEnum(ctx):
         low=1,
         medium=2,
         high=3,
-        unknown=5
+        unknown1=4,
+        unknown2=5
     )
 
 def RevealMapEnum(ctx):
